@@ -32,6 +32,7 @@
 #include <arpa/inet.h>
 
 #include <xtables.h>
+#include <libiptc/libxtc.h>
 
 #ifndef NO_SHARED_LIBS
 #include <dlfcn.h>
@@ -538,14 +539,10 @@ void xtables_register_match(struct xtables_match *me)
 {
 	struct xtables_match **i, *old;
 
-	/* hawk@comx.dk: HACK only compare the first three "numbers"
-	    (eg. major, minor and revision). Assumes a single digit
-	    for each number (eg. 1.4.1) and only compares the first 5
-	    digits.
-	*/
-
-	//if (strcmp(me->version, program_version) != 0) {
-	if (strncmp(me->version, program_version, 5) != 0) {
+	/* hawk@comx.dk: HACK only compare the first n-chars by using
+	 * strncmp instead if strcmp, trying to limit the segfaults
+	 */
+	if (strncmp(me->version, program_version, 16) != 0) {
 		fprintf(stderr, "%s: match `%s' v%s (I'm v%s).\n",
 			program_name, me->name, me->version, program_version);
 		exit(1);
@@ -616,14 +613,10 @@ void xtables_register_target(struct xtables_target *me)
 {
 	struct xtables_target *old;
 
-	/* hawk@comx.dk: HACK only compare the first three "numbers"
-	    (eg. major, minor and revision). Assumes a single digit
-	    for each number (eg. 1.4.1) and only compares the first 5
-	    digits.
-	*/
-
-	//if (strcmp(me->version, program_version) != 0) {
-	if (strncmp(me->version, program_version, 5) != 0) {
+	/* hawk@comx.dk: HACK only compare the first n-chars by using
+	 * strncmp instead if strcmp, trying to limit the segfaults
+	 */
+	if (strncmp(me->version, program_version, 16) != 0) {
 		fprintf(stderr, "%s: target `%s' v%s (I'm v%s).\n",
 			program_name, me->name, me->version, program_version);
 		exit(1);
